API Documentation
=================

Documentation for this project was annotated using pydoctor. The reference then provides insight into using hbspark and should be read thoroughly and referenced throughout developement.

Embedded Reference:
-------------------

.. raw:: html
    :file: _static/embeded-api.html

Raw Reference:
--------------

In case there are issues with the provided embedded option, direct viewing can be done so at this `link <api/index.html>`_.